==> foundry_platform_sdk-0.65.0.tar.gz: foundry_platform_sdk-0.65.0/foundry/v1/datasets/errors/_upload_file_permission_denied.py <==
#  Copyright 2024 Palantir Technologies, Inc.
#
#  Licensed under the Apache License, Version 2.0 (the "License");
#  you may not use this file except in compliance with the License.
#  You may obtain a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
#  Unless required by applicable law or agreed to in writing, software
#  distributed under the License is distributed on an "AS IS" BASIS,
#  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#  See the License for the specific language governing permissions and
#  limitations under the License.


from __future__ import annotations

from dataclasses import dataclass
from typing import Literal

import pydantic
from typing_extensions import TypedDict

from foundry._errors import PalantirRPCException
from foundry.v1.core.models._file_path import FilePath
from foundry.v1.datasets.models._dataset_rid import DatasetRid
from foundry.v1.datasets.models._transaction_rid import TransactionRid


class UploadFilePermissionDeniedParameters(TypedDict):
    """The provided token does not have permission to upload the given file to the given dataset and transaction."""

    __pydantic_config__ = {"extra": "allow"}  # type: ignore

    datasetRid: DatasetRid

    transactionRid: TransactionRid

    path: FilePath


@dataclass
class UploadFilePermissionDenied(PalantirRPCException):
    name: Literal["UploadFilePermissionDenied"]
    parameters: UploadFilePermissionDeniedParameters
    error_instance_id: str


__all__ = ["UploadFilePermissionDenied"]

==> foundry_platform_sdk-0.94.0.tar.gz: foundry_platform_sdk-0.94.0/foundry/v1/datasets/errors/_upload_file_permission_denied.py <==
#  Copyright 2024 Palantir Technologies, Inc.
#
#  Licensed under the Apache License, Version 2.0 (the "License");
#  you may not use this file except in compliance with the License.
#  You may obtain a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
#  Unless required by applicable law or agreed to in writing, software
#  distributed under the License is distributed on an "AS IS" BASIS,
#  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#  See the License for the specific language governing permissions and
#  limitations under the License.


from __future__ import annotations

from dataclasses import dataclass
from typing import Literal

from typing_extensions import TypedDict

from foundry._errors import PermissionDeniedError
from foundry.v1.core.models._file_path import FilePath
from foundry.v1.datasets.models._dataset_rid import DatasetRid
from foundry.v1.datasets.models._transaction_rid import TransactionRid


class UploadFilePermissionDeniedParameters(TypedDict):
    """The provided token does not have permission to upload the given file to the given dataset and transaction."""

    __pydantic_config__ = {"extra": "allow"}  # type: ignore

    datasetRid: DatasetRid

    transactionRid: TransactionRid

    path: FilePath


@dataclass
class UploadFilePermissionDenied(PermissionDeniedError):
    name: Literal["UploadFilePermissionDenied"]
    parameters: UploadFilePermissionDeniedParameters
    error_instance_id: str


__all__ = ["UploadFilePermissionDenied"]
